==> apache-arrow-16.1.0_2.arm64_ventura.bottle.tar.gz: apache-arrow/16.1.0_2/lib/cmake/ArrowFlightSql/ArrowFlightSqlTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "ArrowFlightSql::arrow_flight_sql_shared" for configuration "RELEASE"
set_property(TARGET ArrowFlightSql::arrow_flight_sql_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ArrowFlightSql::arrow_flight_sql_shared PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_flight_sql.1601.0.0.dylib"
  IMPORTED_SONAME_RELEASE "@@HOMEBREW_CELLAR@@/apache-arrow/16.1.0_2/lib/libarrow_flight_sql.1601.dylib"
  )

list(APPEND _cmake_import_check_targets ArrowFlightSql::arrow_flight_sql_shared )
list(APPEND _cmake_import_check_files_for_ArrowFlightSql::arrow_flight_sql_shared "${_IMPORT_PREFIX}/lib/libarrow_flight_sql.1601.0.0.dylib" )

# Import target "ArrowFlightSql::arrow_flight_sql_static" for configuration "RELEASE"
set_property(TARGET ArrowFlightSql::arrow_flight_sql_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ArrowFlightSql::arrow_flight_sql_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_flight_sql.a"
  )

list(APPEND _cmake_import_check_targets ArrowFlightSql::arrow_flight_sql_static )
list(APPEND _cmake_import_check_files_for_ArrowFlightSql::arrow_flight_sql_static "${_IMPORT_PREFIX}/lib/libarrow_flight_sql.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> apache-arrow-18.0.0.arm64_ventura.bottle.tar.gz: apache-arrow/18.0.0/lib/cmake/ArrowFlightSql/ArrowFlightSqlTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "ArrowFlightSql::arrow_flight_sql_shared" for configuration "RELEASE"
set_property(TARGET ArrowFlightSql::arrow_flight_sql_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ArrowFlightSql::arrow_flight_sql_shared PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_flight_sql.1800.0.0.dylib"
  IMPORTED_SONAME_RELEASE "@@HOMEBREW_CELLAR@@/apache-arrow/18.0.0/lib/libarrow_flight_sql.1800.dylib"
  )

list(APPEND _cmake_import_check_targets ArrowFlightSql::arrow_flight_sql_shared )
list(APPEND _cmake_import_check_files_for_ArrowFlightSql::arrow_flight_sql_shared "${_IMPORT_PREFIX}/lib/libarrow_flight_sql.1800.0.0.dylib" )

# Import target "ArrowFlightSql::arrow_flight_sql_static" for configuration "RELEASE"
set_property(TARGET ArrowFlightSql::arrow_flight_sql_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ArrowFlightSql::arrow_flight_sql_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_flight_sql.a"
  )

list(APPEND _cmake_import_check_targets ArrowFlightSql::arrow_flight_sql_static )
list(APPEND _cmake_import_check_files_for_ArrowFlightSql::arrow_flight_sql_static "${_IMPORT_PREFIX}/lib/libarrow_flight_sql.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
